@@ -2,7 +2,7 @@ package WWW::HtmlUnit;
 
 =head1 NAME
 
-WWW::HtmlUnit - Inline::Java based wrapper of the HtmlUnit library
+WWW::HtmlUnit - Inline::Java based wrapper of the HtmlUnit v2.5 library
 
 =head1 SYNOPSIS
 
@@ -30,16 +30,26 @@ so you can automate, scrape, or test javascript-required websites.
 See especially the HtmlUnit documentation on their site for deeper API
 documentation, L<http://htmlunit.sourceforge.net/apidocs/>.
 
+=head1 INSTALLING
+
+There is one problem that I fun into when installing Inline::Java, and thus
+WWW::HtmlUnit, which is telling the installer where to find your java home. It
+turns out this is really really easy, just define the JAVA_HOME environment
+variable before you start your CPAN shell / installer. I do this in
+Debian/Ubuntu:
+
+  apt-get install sun-java6-jdk
+  JAVA_HOME=/usr/lib/jvm/java-6-sun cpan WWW::HtmlUnit
+
+and everything works the way I want! I should submit a patch to the error
+message that Inline::Java spits out...
+
 =cut
 
 use strict;
 use warnings;
 
-our $VERSION = '0.05';
-
-use File::Find;
-use vars qw( $jar_path );
-
+our $VERSION = '0.06';
 
 sub find_jar_path {
     my $self = shift;
@@ -49,6 +59,7 @@ sub find_jar_path {
 }
 
 # This way might be better?
+# use File::Find;
 # sub find_jar_path {
     # my $self = shift;
     # my $module = 'WWW/HtmlUnit';
@@ -71,18 +82,9 @@ sub find_jar_path {
     # return $path;
 # }
 
-BEGIN {
-  $jar_path = find_jar_path();
-}
-
-use Inline (
-  Java => 'STUDY',
-  STUDY => [
-    'com.gargoylesoftware.htmlunit.WebClient',
-    'com.gargoylesoftware.htmlunit.BrowserVersion',
-  ],
-  AUTOSTUDY => 1,
-  CLASSPATH => join ':', map { "$jar_path/$_" } qw(
+sub collect_default_jars {
+    my $jar_path = find_jar_path();
+    return join ':', map { "$jar_path/$_" } qw(
     commons-codec-1.3.jar
     commons-collections-3.2.1.jar
     commons-httpclient-3.1.jar
@@ -98,8 +100,38 @@ use Inline (
     xalan-2.7.1.jar
     xercesImpl-2.8.1.jar
     xml-apis-1.3.04.jar
-  ),
-);
+  );
+}
+
+=head1 MODULE IMPORT PARAMETERS
+
+If you need to include extra .jar files, you can do:
+
+  use HtmlUnit jars => ['/path/to/blah.jar'];
+
+and that wil be added to the list of jars for Inline::Java to autostudy.
+
+=cut
+
+sub import {
+    my $class = shift;
+    my %parameters = @_;
+    my $custom_jars = "";
+    if ($parameters{jars}) {
+        $custom_jars = join(':', @{$parameters{jars}});
+    }
+
+    require Inline;
+    Inline->import(
+      Java => 'STUDY',
+      STUDY => [
+        'com.gargoylesoftware.htmlunit.WebClient',
+        'com.gargoylesoftware.htmlunit.BrowserVersion',
+      ],
+      AUTOSTUDY => 1,
+      CLASSPATH => collect_default_jars() . ":" . $custom_jars
+    );
+}
 
 =head1 METHODS
 
@@ -125,6 +157,32 @@ sub new {
   }
 }
 
+=head1 DEPENDENCIES
+
+When installed using the CPAN shell, all dependencies besides java itself will
+be installed. This includes the HtmlUnit jar files, and in fact those files
+make up the bulk of the distribution.
+
+=head1 TIPS
+
+How do I do HTTP authentication?
+
+  my $credentialsProvider = $webclient->getCredentialsProvider;                           
+  $credentialsProvider->addCredentials($username, $password);                
+
+How do I turn off SSL certificate checking?
+
+  $webclient->setUseInsecureSSL(1);
+
+=head1 TODO
+
+=over 4
+
+=item * Capture HtmlUnit output to a variable
+
+=item * Use that to have a quiet-mode
+
+=back
 
 =head1 SEE ALSO
 
